@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::DAGOLDEN;
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.055'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -15,7 +15,7 @@ use Dist::Zilla 4.300038; # fixed MetaYML encoding
 use Dist::Zilla::PluginBundle::Filter ();
 use Dist::Zilla::PluginBundle::Git 1.121010 ();
 
-use Dist::Zilla::Plugin::Authority 1.006 ();
+use Dist::Zilla::Plugin::Authority 1.006  ();
 use Dist::Zilla::Plugin::Bugtracker 1.110 ();
 use Dist::Zilla::Plugin::CheckChangesHasContent ();
 use Dist::Zilla::Plugin::CheckExtraTests        ();
@@ -23,25 +23,25 @@ use Dist::Zilla::Plugin::CheckMetaResources 0.001  ();
 use Dist::Zilla::Plugin::CheckPrereqsIndexed 0.002 ();
 use Dist::Zilla::Plugin::ContributorsFromGit 0.004 ();
 use Dist::Zilla::Plugin::CopyFilesFromBuild ();
-use Dist::Zilla::Plugin::CPANFile ();
+use Dist::Zilla::Plugin::CPANFile           ();
 use Dist::Zilla::Plugin::Git::NextVersion   ();
-use Dist::Zilla::Plugin::GithubMeta 0.36 ();
+use Dist::Zilla::Plugin::GithubMeta 0.36       ();
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
 use Dist::Zilla::Plugin::MetaNoIndex ();
-use Dist::Zilla::Plugin::MetaProvides::Package 1.14 (); # hides DB/main/private packages
+use Dist::Zilla::Plugin::MetaProvides::Package 1.14 (); # hides private packages
 use Dist::Zilla::Plugin::MinimumPerl ();
-use Dist::Zilla::Plugin::OurPkgVersion 0.004 (); # TRIAL comment support
+use Dist::Zilla::Plugin::OurPkgVersion 0.004 ();        # TRIAL comment support
 use Dist::Zilla::Plugin::PodWeaver ();
-use Dist::Zilla::Plugin::ReadmeAnyFromPod 0.120051 ();
-use Dist::Zilla::Plugin::TaskWeaver 0.101620       ();
-use Dist::Zilla::Plugin::Test::Compile 2.023     ();
+use Dist::Zilla::Plugin::ReadmeAnyFromPod 0.120051     ();
+use Dist::Zilla::Plugin::TaskWeaver 0.101620           ();
+use Dist::Zilla::Plugin::Test::Compile 2.036           (); # various features
 use Dist::Zilla::Plugin::Test::MinimumVersion 2.000003 ();
 use Dist::Zilla::Plugin::Test::Perl::Critic ();
-use Dist::Zilla::Plugin::Test::PodSpelling 2.006001 (); # Pod::Wordlist
-use Test::Portability::Files 0.06 (); # buggy before that
-use Dist::Zilla::Plugin::Test::Portability   ();
-use Dist::Zilla::Plugin::Test::ReportPrereqs ();
-use Dist::Zilla::Plugin::Test::Version       ();
+use Dist::Zilla::Plugin::Test::PodSpelling 2.006001 ();    # Pod::Wordlist
+use Test::Portability::Files 0.06                   ();    # buggy before that
+use Dist::Zilla::Plugin::Test::Portability ();
+use Dist::Zilla::Plugin::Test::ReportPrereqs 0.008 ();     # warn on unsatisfied
+use Dist::Zilla::Plugin::Test::Version ();
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 with 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
@@ -190,7 +190,7 @@ has darkpan => (
     isa     => 'Bool',
     lazy    => 1,
     default => sub {
-        exists $_[0]->payload->{darkpan} ? $_[0]->payload->{darkpan} : 0
+        exists $_[0]->payload->{darkpan} ? $_[0]->payload->{darkpan} : 0;
     },
 );
 
@@ -226,11 +226,17 @@ sub configure {
         # gather and prune
         (
             $self->no_git
-            ? [ 'GatherDir' => { exclude_filename => [qw/README.pod README.mkdn META.json cpanfile/] } ] # core
-            : [ 'Git::GatherDir' => { exclude_filename => [qw/README.pod README.mkdn META.json cpanfile/] } ]
+            ? [
+                'GatherDir' =>
+                  { exclude_filename => [qw/README.pod README.mkdn META.json cpanfile/] }
+              ] # core
+            : [
+                'Git::GatherDir' =>
+                  { exclude_filename => [qw/README.pod README.mkdn META.json cpanfile/] }
+            ]
         ),
-        'PruneCruft',                                                               # core
-        'ManifestSkip',                                                             # core
+        'PruneCruft',   # core
+        'ManifestSkip', # core
 
         # file munging
         'OurPkgVersion',
@@ -243,10 +249,15 @@ sub configure {
 
         # generated distribution files
         'ReadmeAnyFromPod', # in build dir
-        'License',                                # core
+        'License',          # core
 
         # generated t/ tests
-        [ 'Test::Compile' => { fake_home => 1 } ],
+        [
+            'Test::Compile' => {
+                fake_home => 1,
+                xt_mode   => 1,
+            }
+        ],
         (
             $self->no_minimum_perl
             ? ()
@@ -256,13 +267,11 @@ sub configure {
 
         # generated xt/ tests
         (
-            $self->no_spellcheck
-            ? ()
+            $self->no_spellcheck ? ()
             : [ 'Test::PodSpelling' => { stopwords => $self->stopwords } ]
         ),
         (
-            $self->no_critic
-            ? ()
+            $self->no_critic ? ()
             : ('Test::Perl::Critic')
         ),
         'MetaTests',      # core
@@ -276,8 +285,9 @@ sub configure {
         'Test::Version',
 
         # metadata
-        [ 'Authority' => {
-                authority => $self->authority,
+        [
+            'Authority' => {
+                authority  => $self->authority,
                 do_munging => 0,
             }
         ],
@@ -299,16 +309,18 @@ sub configure {
             ? ()
             : [
                 GithubMeta => {
-                    remote => [ qw(origin github) ],
+                    remote => [qw(origin github)],
                     issues => $self->github_issues,
                 }
-              ],
+            ],
         ),
         (
-            ( $self->no_git || $self->darkpan || ! $self->github_issues )
-            ? (
+            ( $self->no_git || $self->darkpan || !$self->github_issues ) ? (
                 # fake out Pod::Weaver::Section::Support
-                [ 'Bugtracker' => { mailto => '', $self->darkpan ? ( web => "http://localhost/" ) : () } ],
+                [
+                    'Bugtracker' =>
+                      { mailto => '', $self->darkpan ? ( web => "http://localhost/" ) : () }
+                ],
               )
             : ()
         ),
@@ -316,29 +328,27 @@ sub configure {
             ( $self->no_git || $self->darkpan )
             ? (
                 # fake out Pod::Weaver::Section::Support
-                [ 'MetaResources' => { map {; "repository.$_" => "http://localhost/" } qw/url web/ } ],
+                [
+                    'MetaResources' => { map { ; "repository.$_" => "http://localhost/" } qw/url web/ }
+                ],
               )
             : ()
         ),
 
-        'MetaYAML',                                           # core
-        'MetaJSON',                                           # core
+        'MetaYAML', # core
+        'MetaJSON', # core
         'CPANFile',
 
         # build system
-        'ExecDir',                                            # core
-        'ShareDir',                                           # core
-        [ 'MakeMaker' => { eumm_version => '6.17' } ],        # core
+        'ExecDir',  # core
+        'ShareDir', # core
+        [ 'MakeMaker' => { eumm_version => '6.17' } ], # core
 
         # copy files from build back to root for inclusion in VCS
-        [
-            CopyFilesFromBuild => {
-                copy => 'cpanfile',
-            }
-        ],
+        [ CopyFilesFromBuild => { copy => 'cpanfile', } ],
 
         # manifest -- must come after all generated files
-        'Manifest',                                           # core
+        'Manifest',                                    # core
 
         # before release
         (
@@ -350,8 +360,8 @@ sub configure {
         'CheckPrereqsIndexed',
         'CheckChangesHasContent',
         'CheckExtraTests',
-        'TestRelease',                                        # core
-        'ConfirmRelease',                                     # core
+        'TestRelease',                                 # core
+        'ConfirmRelease',                              # core
 
         # release
         ( $self->fake_release || $self->darkpan ? 'FakeRelease' : 'UploadToCPAN' ), # core
@@ -417,7 +427,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.054
+version 0.055
 
 =head1 SYNOPSIS
 
@@ -455,12 +465,8 @@ following dist.ini:
    [ReadmeAnyFromPod]     ; from Pod (runs after PodWeaver)
  
    ; t tests
-   [Test::Compile]     ; make sure .pm files all compile
-   fake_home = 1       ; fakes $ENV{HOME} just in case
- 
    [Test::MinimumPerl]
    max_target_perl = 5.010
- 
    [Test::ReportPrereqs] ; show prereqs in automated test output
  
    ; xt tests
@@ -472,6 +478,9 @@ following dist.ini:
    [Test::Portability] ; xt/release/portability.t (of file name)
    options = test_one_dot = 0
    [Test::Version]     ; xt/release/test-version.t
+   [Test::Compile]     ; make sure .pm files all compile
+   fake_home = 1       ; fakes $ENV{HOME} just in case
+   xt_mode = 1         ; puts files in xt, not t
  
    ; metadata
    [AutoPrereqs]       ; find prereqs from code
